@@ -1,20 +1,3 @@
-#' @title Function \code{plot_graph}
-#' @description Plot the dependency structure of your workflow
-#' @export
-#' @param plan workflow plan data frame, same as for function 
-#' \code{\link{make}()}.
-#' @param targets names of targets to bulid, same as for function
-#' \code{\link{make}()}.
-#' @param envir environment to import from, same as for function
-#' \code{\link{make}()}.
-#' @param verbose logical, whether to output messages to the console.
-plot_graph = function(plan, targets = drake::possible_targets(plan), 
-  envir = parent.frame(), verbose = TRUE){
-  force(envir)
-  build_graph(plan = plan, targets = targets, envir = envir,
-    verbose = verbose) %>% plot.igraph
-}
-
 #' @title Function \code{build_graph}
 #' @description Make a graph of the dependency structure of your workflow.
 #' @details This function returns an igraph object representing how
@@ -22,6 +5,7 @@ plot_graph = function(plan, targets = drake::possible_targets(plan),
 #' (\code{help(package = "igraph")}). To plot the graph, call
 #' to \code{\link{plot.igraph}()} on your graph, or just use 
 #' \code{\link{plot_graph}()} from the start.
+#' @seealso \code{\link{plot_graph}}
 #' @export
 #' @param plan workflow plan data frame, same as for function
 #' \code{\link{make}()}.
@@ -30,6 +14,12 @@ plot_graph = function(plan, targets = drake::possible_targets(plan),
 #' @param envir environment to import from, same as for function
 #' \code{\link{make}()}.
 #' @param verbose logical, whether to output messages to the console.
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' g <- build_graph(my_plan)
+#' class(g)
+#' }
 build_graph = function(plan, targets = drake::possible_targets(plan), 
   envir = parent.frame(), verbose = TRUE){
   force(envir)
@@ -38,16 +28,18 @@ build_graph = function(plan, targets = drake::possible_targets(plan),
   imports = as.list(envir)
   assert_unique_names(imports = names(imports), targets = plan$target,
     envir = envir, verbose = verbose)
+  true_import_names = setdiff(names(imports), targets)
+  imports = imports[true_import_names]
   import_deps = lapply(imports, import_dependencies)
   command_deps = lapply(plan$command, command_dependencies)
   names(command_deps) = plan$target
   dependency_list = c(command_deps, import_deps)
   keys = names(dependency_list)
   vertices = c(keys, unlist(dependency_list)) %>% unique
-  graph = make_empty_graph() + vertices(vertices)
-  for(key in keys)
-    for(dependency in dependency_list[[key]])
-      graph = graph + edge(dependency, key)
+  from = unlist(dependency_list) %>% unname
+  to = rep(keys, times = sapply(dependency_list, length))
+  edges = rbind(from, to) %>% as.character
+  graph = make_empty_graph() + vertex(vertices) + edge(edges)
   ignore = lapply(targets, function(vertex)
     subcomponent(graph = graph, v = vertex, mode = "in")$name
   ) %>% unlist %>% unique %>% setdiff(x = vertices)
@@ -67,6 +59,11 @@ build_graph = function(plan, targets = drake::possible_targets(plan),
 #' \code{\link{make}()}.
 #' @param envir environment to import from, same as for function
 #' \code{\link{make}()}.
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' tracked(my_plan)
+#' }
 tracked = function(plan, targets = drake::possible_targets(plan),
   envir = parent.frame()){
   force(envir)
