@@ -20,6 +20,15 @@
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
 #' @param cache a storr cache. Mainly for internal use.
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' make(my_plan)
+#' readd(reg1)
+#' readd(small)
+#' readd("large", character_only = TRUE)
+#' readd("'report.md'") # just a fingerprint of the file (md5 sum)
+#' }
 readd = function(target, character_only = FALSE, path = getwd(), 
   search = TRUE, cache = NULL){
   if(is.null(cache)) cache = get_cache(path = path, search = search)
@@ -58,6 +67,18 @@ readd = function(target, character_only = FALSE, path = getwd(),
 #' current working directory only.
 #' @param envir environment to load objects into. Defaults to the
 #' calling environment (current workspace).
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' make(my_plan)
+#' loadd(reg1) # now check ls()
+#' reg1
+#' loadd(small)
+#' small
+#' loadd(list = c("small", "large"))
+#' loadd(imported_only = TRUE) # load all imported objects and functions
+#' loadd() # load everything, including built targets
+#' }
 loadd = function(..., list = character(0),
   imported_only = FALSE, path = getwd(), 
   search = TRUE, envir = parent.frame()){
@@ -94,6 +115,12 @@ load_target = Vectorize(function(target, cache, envir){
 #' @param search logical. If \code{TRUE}, search parent directories
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' make(my_plan)
+#' read_config()
+#' }
 read_config = function(path = getwd(), search = TRUE){
   cache = get_cache(path = path, search = search)
   if(is.null(cache)) stop("cannot find drake cache.")
@@ -114,27 +141,41 @@ read_config = function(path = getwd(), search = TRUE){
 #' @param search logical. If \code{TRUE}, search parent directories
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' make(my_plan)
+#' read_plan()
+#' }
 read_plan = function(path = getwd(), search = TRUE){
   read_config(path = path, search = search)$plan
 }
 
 #' @title Function \code{read_graph}
-#' @description Read the dependency graph of your targets
+#' @description Read the igraph-style dependency graph of your targets
 #' from your last attempted call to \code{\link{make}()}.
-#' @seealso \code{\link{read_config}}
+#' For better graphing utilities, see \code{\link{plot_graph}()}
+#' and related functions.
+#' @seealso \code{\link{plot_graph}}, \code{\link{read_config}}
 #' @export
 #' @return either a plot or an igraph object, depending
 #' on \code{plot}
-#' @param plot logical, whether to plot the graph or 
-#' simply return the graph as an igraph object.
 #' @param path Root directory of the drake project,
 #' or if \code{search} is \code{TRUE}, either the
 #' project root or a subdirectory of the project.
 #' @param search logical. If \code{TRUE}, search parent directories
 #' to find the nearest drake cache. Otherwise, look in the
 #' current working directory only.
-read_graph = function(plot = TRUE, path = getwd(), search = TRUE){
-  graph = read_config(path = path, search = search)$graph
-  if(plot) plot.igraph(graph)
-  else graph
+#' @param ... arguments to \code{visNetwork()} via \code{\link{plot_graph}()}
+#' @examples
+#' \dontrun{
+#' load_basic_example()
+#' make(my_plan)
+#' g <- read_graph(plot = FALSE)
+#' class(g)
+#' read_graph() # Actually plot the graph as an interactive visNetwork widget.
+#' }
+read_graph = function(path = getwd(), search = TRUE, ...){
+  config = read_config(path = path, search = search)
+  return(config$graph)
 }
